from .CxPortalWebService import (
    add_license_expiration_notification,
    create_new_preset,
    create_scan_report,
    delete_preset,
    export_preset,
    export_queries,
    get_compare_scan_results,
    get_import_queries_status,
    get_path_comments_history,
    get_user_profile_data,
    get_queries_categories,
    get_query_collection,
    get_query_id_by_language_group_and_query_name,
    get_name_of_user_who_marked_false_positive_from_comments_history,
    get_preset_list,
    get_result_path,
    get_results_for_scan,
    get_server_license_data,
    get_server_license_summary,
    delete_project,
    delete_projects,
    get_version_number,
    get_version_number_as_int,
    import_preset,
    import_queries,
    lock_scan,
    unlock_scan,
)

from .CxAuditWebService import (
    get_files_extensions,
    get_source_code_for_scan,
    upload_queries,
)
